@@ -46,6 +46,11 @@ from .parser import (
     simple_code_chunk_parse,
 )
 
+if sys.version_info > (3, 8):
+    AstModule = ast.Module
+else:
+    AstModule = lambda nodelist, type_ignores: ast.Module(nodelist)
+
 try:
     import matplotlib.artist
     import matplotlib.figure
@@ -96,7 +101,9 @@ SKIP_OUTPUT_SEMAPHORE = object()
 
 
 class CodeTimer:
-    """Context handler for timing code, use inside a `with` statement."""
+    """
+    Context handler for timing code, use inside a `with` statement.
+    """
 
     _start_time: datetime.datetime
     duration: typing.Optional[datetime.timedelta] = None
@@ -119,7 +126,9 @@ class CodeTimer:
 
 
 class StdoutBuffer(TextIOWrapper):
-    """Used for capturing output to stdout."""
+    """
+    Used for capturing output to stdout.
+    """
 
     def write(self, string: typing.Union[bytes, str]) -> int:
         if isinstance(string, str):
@@ -128,14 +137,18 @@ class StdoutBuffer(TextIOWrapper):
 
 
 class DocumentCompilationResult(typing.NamedTuple):
-    """Stores references to Parameters and Code that is parsed from a Document."""
+    """
+    Stores references to Parameters and Code that is parsed from a Document.
+    """
 
     parameters: typing.List[Parameter] = []
     code: typing.List[ExecutableCode] = []
 
 
 class DocumentCompiler:
-    """Parse an executable document (`Article`) and cache references to its parameters and code nodes."""
+    """
+    Parse an executable document (`Article`) and cache references to its parameters and code nodes.
+    """
 
     TARGET_LANGUAGE = "python"
 
@@ -190,7 +203,9 @@ class DocumentCompiler:
         item: typing.Union[CodeChunk, CodeExpression],
         compilation_result: DocumentCompilationResult,
     ) -> None:
-        """Parse a CodeChunk or CodeExpression and add it to `compilation_result.code` list."""
+        """
+        Parse a CodeChunk or CodeExpression and add it to `compilation_result.code` list.
+        """
         if isinstance(item, CodeChunk):
             cc_result, item = Interpreter.compile_code_chunk(item)
 
@@ -207,14 +222,18 @@ class DocumentCompiler:
     def traverse_dict(
         self, _dict: dict, compilation_result: DocumentCompilationResult
     ) -> None:
-        """Traverse into each item of a dict."""
+        """
+        Traverse into each item of a dict.
+        """
         for child in _dict.values():
             self.handle_item(child, compilation_result)
 
     def traverse_list(
         self, _list: typing.List, compilation_result: DocumentCompilationResult
     ) -> None:
-        """Traverse into each element in a list."""
+        """
+        Traverse into each element in a list.
+        """
         for child in _list:
             self.handle_item(child, compilation_result)
 
@@ -298,7 +317,9 @@ class Interpreter:
 
     @staticmethod
     def compile(node: Node) -> Node:
-        """Compile a `CodeChunk`"""
+        """
+        Compile a `CodeChunk`.
+        """
         if isinstance(node, CodeChunk) and Interpreter.is_python_code(node):
             return Interpreter.compile_code_chunk(node)[1]
         raise CapabilityError("compile", node=node)
@@ -306,7 +327,9 @@ class Interpreter:
     def execute(
         self, node: Node, parameter_values: typing.Dict[str, typing.Any] = None
     ) -> Node:
-        """Execute a `CodeChunk` or `CodeExpression`"""
+        """
+        Execute a `CodeChunk` or `CodeExpression`.
+        """
         _locals = self.locals
         if parameter_values is not None:
             _locals.update(parameter_values)
@@ -322,13 +345,17 @@ class Interpreter:
 
     @staticmethod
     def is_python_code(code: typing.Union[CodeChunk, CodeExpression]) -> bool:
-        """Is a `CodeChunk` or `CodeExpression` Python code?"""
+        """
+        Is a `CodeChunk` or `CodeExpression` Python code?
+        """
         return code.programmingLanguage.lower() in Interpreter.PROGRAMMING_LANGUAGES
 
     def execute_code_expression(
         self, expression: CodeExpression, _locals: typing.Dict[str, typing.Any]
     ) -> CodeExpression:
-        """Evaluate `CodeExpression.text`, and get the result. Catch any exception the occurs."""
+        """
+        Evaluate `CodeExpression.text`, and get the result. Catch any exception the occurs.
+        """
         try:
             # pylint: disable=W0123  # Disable warning that eval is being used.
             expression.output = self.decode_output(
@@ -343,7 +370,9 @@ class Interpreter:
     def execute_code_chunk(
         self, chunk_execution: CodeChunkExecution, _locals: typing.Dict[str, typing.Any]
     ) -> CodeChunk:
-        """Execute a `CodeChunk` that has been parsed and stored in a `CodeChunkExecution`."""
+        """
+        Execute a `CodeChunk` that has been parsed and stored in a `CodeChunkExecution`.
+        """
         chunk, parse_result = chunk_execution
 
         if parse_result.chunk_ast is None:
@@ -467,14 +496,15 @@ class Interpreter:
             # definition) so it can be executed with `exec`.
             capture_result = False
             run_function = exec
-            mod = ast.Module()
-            mod.body = [statement]
+            mod = AstModule([statement], [])
             code_to_run = compile(mod, "<ast>", "exec")
         return capture_result, code_to_run, run_function
 
     @staticmethod
     def value_is_mpl(value: typing.Any) -> bool:
-        """Basic type checking to determine if a variable is a MatPlotLib figure."""
+        """
+        Basic type checking to determine if a variable is a matplotlib figure.
+        """
         if not MPL_AVAILABLE:
             return False
 
@@ -498,7 +528,9 @@ class Interpreter:
 
     @staticmethod
     def decode_dataframe(data_frame: DataFrame) -> Datatable:
-        """Decode a pandas `DataFrame` into a `Datatable`"""
+        """
+        Decode a pandas `DataFrame` into a `Datatable`.
+        """
         columns = []
 
         for column_name in data_frame.columns:
